@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::PortabilityTests;
 # ABSTRACT: (DEPRECATED) Release tests for portability
-our $VERSION = '2.0.2'; # VERSION
+our $VERSION = '2.000003'; # VERSION
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::Portability';
 
@@ -26,7 +26,7 @@ Dist::Zilla::Plugin::PortabilityTests - (DEPRECATED) Release tests for portabili
 
 =head1 VERSION
 
-version 2.0.2
+version 2.000003
 
 =head1 SYNOPSIS
 
@@ -45,12 +45,7 @@ The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-Por
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-Test-Portability/>.
-
-The development version lives at L<http://github.com/doherty/Dist-Zilla-Plugin-Test-Portability>
-and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Test-Portability.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::Test::Portability/>.
 
 =head1 SOURCE
 
@@ -59,10 +54,8 @@ and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Test-Portabi
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<https://github.com/doherty/Dist-Zilla-Plugin-Test-Portability/issues>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://github.com/doherty/Dist-Zilla-Plugin-Test-Portability/issues>.
 
 =head1 AUTHORS
 
